rnalysis.filtering.FoldChangeFilter.split\_fold\_change\_direction
==================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.split_fold_change_direction